# tempath 0.1.0

Function library for creating randomly filled files and directories,
that will be automatically removed at runtime end.

![PyBen](./assets/tempath.png)

![GitHub repo size](https://img.shields.io/github/repo-size/alexpdev/tempath)
![GitHub contributors](https://img.shields.io/github/license/alexpdev/tempath)
![GitHub stars](https://img.shields.io/badge/rating-99-green)

## Prerequisites

* Python3 installed and enabled

## Installing PyBen

To install Tempath, follow these steps:

Using pip:

```bash
pip install tempath
```

Using git:

```cmd
git clone https://github.com/alexpdev/tempath.git
```

The full API includes many other functions and classes as well.
See docs for more full API.

## License

This project uses the following license: GNU LGPL v3
